import socket
import struct
import fcntl
import logging
import subprocess
import uci
import json

SIOCGIFADDR = 0x8915
# Is must be a bytes object to be used by struct.pack
IFNAME = b'eth0'

logger = logging.getLogger(__name__)

def get_eth_address():
    address=''
    sckt = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
    try:
        ifreq = struct.pack('256s', IFNAME[:15])
        res = fcntl.ioctl(sckt.fileno(), SIOCGIFADDR, ifreq)
        address = socket.inet_ntoa(res[20:24])
    except Exception as err:
        logger.error('Error getting ethernet address: {}'.format(err))
        raise err

    return address

def get_firmware_version():
    version = ''
    with open('/barix/info/VERSION', 'r') as f:
        version = f.read().rsplit()[0]
    return version

def get_flexa_app_version():
    version = ''
    try:
        u = uci.Uci()
        version = u.get("flexa_agent", "service", "package_version")
    except Exception as err:
        logger.error("Error getting app version: {}".format(err))
        raise err

    return version

def get_hw_type():
    hwType = ''
    try:
        # qiba-spi-get-production-info.sh always returns an error
        hwType = subprocess.check_output('qiba-spi-get-production-info.sh -w', shell=True, stderr=subprocess.STDOUT)
    except subprocess.CalledProcessError as e:
        hwType = str(e.output.decode('utf-8')).replace('\n', '')
    except Exception as err:
        logger.error("Error getting hw type: {}".format(err))
        raise err

    return hwType

def get_eth_mac():
    mac = ''
    try:
        output = subprocess.check_output(['qiba-get-params.sh'])
        for line in output.splitlines():
            key, value = line.decode().split("=", 1)
            if key == 'ethaddr':
                mac = value
                break
    except subprocess.CalledProcessError as cmdError:
        logger.error('{} returned error code {}'.format(cmdError.cmd, cmd.returncode))
        raise cmdError

    return mac

def get_cpu_snr():
    snr = ''
    try:
        output = subprocess.check_output(['qiba-get-params.sh'])
        for line in output.splitlines():
            key, value = line.decode().split("=", 1)
            if key == 'serialno':
                snr = value
                break
    except subprocess.CalledProcessError as cmdError:
        logger.error('{} returned error code {}'.format(cmdError.cmd, cmd.returncode))
        raise cmdError

    return snr

def get_flexa_config():
    config = {}
    try:
        with open('/mnt/data/package/config.json', 'r') as f:
            config = json.load(f)['AppParam']
    except Exception as err:
        logger.error('Error reading configuration file: {}'.format(err))
        raise err

    return config

